@@ -35,10 +35,6 @@
 #include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
-#ifdef HAVE_SQLITE
-#include <sqlite3.h>
-#endif
-
 #define HILDON_DESKTOP_NOTIFICATION_MANAGER_GET_PRIVATE(object) \
         (G_TYPE_INSTANCE_GET_PRIVATE ((object), HILDON_DESKTOP_TYPE_NOTIFICATION_MANAGER, HildonDesktopNotificationManagerPrivate))
 
@@ -56,6 +52,63 @@ static gint signals[N_SIGNALS];
 
 #define HILDON_DESKTOP_NOTIFICATION_MANAGER_ICON_SIZE  48
 
+#ifdef HAVE_SQLITE
+
+#define SQLITE_OK     0 
+#define SQLITE_ERROR  1 
+
+typedef struct _sqlite3 sqlite3;
+
+typedef int        (*sqlite3_callback)   (void *,
+                                          int,
+                                          char**, 
+                                          char**);
+
+static char       *(*sqlite3_mprintf)    (const char*, ...);
+
+static void        (*sqlite3_free_table) (char **result);
+
+static int         (*sqlite3_get_table)  (sqlite3 *, 
+                                          const char *sql, 
+                                          char ***resultp, 
+                                          int *nrow, 
+                                          int *ncolumn, 
+                                          char **errmsg);
+
+static int         (*sqlite3_open)       (const char *filename, 
+                                          sqlite3 **ppDb);
+
+static int         (*sqlite3_close)      (sqlite3 *);
+
+static void        (*sqlite3_free)       (void *);
+
+static int         (*sqlite3_exec)       (sqlite3 *, 
+                                          const char *sql, 
+                                          sqlite3_callback,
+                                          void *, 
+                                          char **errmsg);
+
+static const char *(*sqlite3_errmsg)     (sqlite3 *);
+
+static struct SqliteDlMapping
+{
+  const char *fn_name;
+  gpointer *fn_ptr_ref;
+} sqlite_dl_mapping[] =
+{
+#define MAP_SYMBOL(a) { #a, (void *)&a }
+  MAP_SYMBOL (sqlite3_mprintf),
+  MAP_SYMBOL (sqlite3_open),
+  MAP_SYMBOL (sqlite3_errmsg),
+  MAP_SYMBOL (sqlite3_close),
+  MAP_SYMBOL (sqlite3_free),
+  MAP_SYMBOL (sqlite3_exec),
+  MAP_SYMBOL (sqlite3_get_table),
+  MAP_SYMBOL (sqlite3_free_table)
+#undef MAP_SYMBOL
+};
+#endif
+
 struct _HildonDesktopNotificationManagerPrivate
 {
   DBusGConnection *connection;
@@ -82,6 +135,42 @@ enum
   HD_NM_HINT_TYPE_UCHAR
 };
 
+#ifdef HAVE_SQLITE
+static void
+open_libsqlite3 ()
+{
+  static gboolean done = FALSE;
+
+  if (!done)
+  {
+    int i;
+    GModule *sqlite;
+
+    done = TRUE;
+
+    sqlite = g_module_open ("libsqlite3.so.0", G_MODULE_BIND_LAZY | G_MODULE_BIND_LOCAL);
+
+    if (!sqlite)
+      return;
+
+    for (i = 0; i < G_N_ELEMENTS (sqlite_dl_mapping); i++)
+    {
+      if (!g_module_symbol (sqlite, sqlite_dl_mapping[i].fn_name,
+                            sqlite_dl_mapping[i].fn_ptr_ref))
+      {
+        g_warning ("Missing symbol '%s' in libsqlite3", sqlite_dl_mapping[i].fn_name);
+        g_module_close (sqlite);
+
+        for (i = 0; i < G_N_ELEMENTS (sqlite_dl_mapping); i++)
+          sqlite_dl_mapping[i].fn_ptr_ref = NULL;
+
+        return;
+      }
+    }
+  }
+}
+#endif
+
 static void                            
 hint_value_free (GValue *value)
 {
@@ -315,6 +404,7 @@ hildon_desktop_notification_manager_load_row (void *data,
 		      HD_NM_COL_HINTS, hints,
 		      HD_NM_COL_TIMEOUT, (gint) g_ascii_strtod (argv[5], NULL),
 		      HD_NM_COL_REMOVABLE, TRUE,
+		      HD_NM_COL_ACK, FALSE,
 		      HD_NM_COL_SENDER, argv[6],
 		      -1);
 
@@ -326,7 +416,7 @@ hildon_desktop_notification_manager_db_load (HildonDesktopNotificationManager *n
 {
   gchar *error;
   
-  g_return_if_fail(nm->priv->db != NULL);
+  g_return_if_fail (nm->priv->db != NULL);
   
   if (sqlite3_exec (nm->priv->db, 
 		    "SELECT * FROM notifications",
@@ -631,7 +721,7 @@ hildon_desktop_notification_manager_db_delete (HildonDesktopNotificationManager
 {
   gchar *sql;
   gint result;
-        
+
   result = hildon_desktop_notification_manager_db_exec (nm, "BEGIN TRANSACTION");
 
   if (result != SQLITE_OK) goto rollback;
@@ -690,6 +780,7 @@ hildon_desktop_notification_manager_init (HildonDesktopNotificationManager *nm)
     G_TYPE_POINTER,
     G_TYPE_INT,
     G_TYPE_BOOLEAN,
+    G_TYPE_BOOLEAN,
     G_TYPE_STRING
   };
 
@@ -745,11 +836,18 @@ hildon_desktop_notification_manager_init (HildonDesktopNotificationManager *nm)
                                        G_OBJECT (nm));
 
 #ifdef HAVE_SQLITE
+  nm->priv->db = NULL;
+
+  open_libsqlite3 ();
+
+  if (sqlite3_open == NULL)
+    return;
+
   notifications_db = g_build_filename (g_get_home_dir (), 
 		  		       ".osso/hildon-desktop",
 				       "notifications.db",
 				       NULL); 
-  
+
   result = sqlite3_open (notifications_db, &nm->priv->db);
 
   g_free (notifications_db);
@@ -1039,6 +1137,7 @@ hildon_desktop_notification_manager_notify (HildonDesktopNotificationManager *nm
 		        HD_NM_COL_HINTS, hints_copy,
 		        HD_NM_COL_TIMEOUT, timeout,
 			HD_NM_COL_REMOVABLE, TRUE,
+			HD_NM_COL_ACK, FALSE,
 			HD_NM_COL_SENDER, dbus_g_method_get_sender (context),
 		        -1);
 
@@ -1067,6 +1166,7 @@ hildon_desktop_notification_manager_notify (HildonDesktopNotificationManager *nm
 			HD_NM_COL_SUMMARY, summary,
 			HD_NM_COL_BODY, body,
 			HD_NM_COL_REMOVABLE, FALSE,
+			HD_NM_COL_ACK, FALSE,
 			-1);
 
 #ifdef HAVE_SQLITE
@@ -1224,13 +1324,13 @@ gboolean
 hildon_desktop_notification_manager_get_server_info (HildonDesktopNotificationManager *nm,
                                          	     gchar                **out_name,
                                          	     gchar                **out_vendor,
-                                         	     gchar                **out_version,
-                                         	     gchar                **out_spec_ver)
+                                         	     gchar                **out_version/*,
+                                         	     gchar                **out_spec_ver*/)
 {
   *out_name     = g_strdup ("Hildon Desktop Notification Manager");
   *out_vendor   = g_strdup ("Nokia");
   *out_version  = g_strdup (VERSION);
-  *out_spec_ver = g_strdup ("0.9");
+  /**out_spec_ver = g_strdup ("0.9");*/
 
   return TRUE;
 }
@@ -1487,3 +1587,56 @@ hildon_desktop_notification_manager_call_action (HildonDesktopNotificationManage
     g_free (dest);
   }
 }
+
+void
+hildon_desktop_notification_manager_close_all (HildonDesktopNotificationManager *nm)
+{
+  GtkTreeIter iter;
+
+  if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (nm), &iter))
+  {
+    GHashTable *hints;
+    GValue *hint;
+    gchar *dest;
+    gint id;
+    gboolean persistent;
+    
+    do
+    {
+      gtk_tree_model_get (GTK_TREE_MODEL (nm),
+                          &iter,
+			  HD_NM_COL_HINTS, &hints,
+                          HD_NM_COL_ID, &id,
+			  HD_NM_COL_SENDER, &dest,
+                          -1);
+
+      hint = g_hash_table_lookup (hints, "persistent");
+
+      persistent = hint != NULL && g_value_get_uchar (hint);
+
+      hildon_desktop_notification_manager_notification_closed (nm, id, dest, persistent);
+    
+      g_free (dest);
+    }
+    while (gtk_list_store_remove (GTK_LIST_STORE (nm), &iter));
+  }	  
+}
+
+void
+hildon_desktop_notification_manager_call_dbus_callback (HildonDesktopNotificationManager *nm,
+		                                        const gchar *dbus_call)
+{ 
+  DBusMessage *message;
+	
+  g_return_if_fail (HILDON_DESKTOP_IS_NOTIFICATION_MANAGER (nm));
+  g_return_if_fail (dbus_call != NULL);
+
+  message = hildon_desktop_notification_manager_message_from_desc (nm, dbus_call); 
+
+  if (message != NULL)
+  {
+    dbus_connection_send (dbus_g_connection_get_connection (nm->priv->connection), 
+    		          message, 
+    		          NULL);
+  }
+}
