@@ -116,6 +116,7 @@ struct _HDHomeWindowPrivate
   Picture           background_picture;
 
   gboolean          screen_is_off;
+  gboolean          is_background;
 
   gboolean          selecting_applets;
   guint             save_area_timeout;
@@ -1519,6 +1520,10 @@ static void
 hd_home_window_osso_display_state_cb (osso_display_state_t      state,
                                       gpointer                  window)
 {
+  /* We don't do anything when the screen is dimmed, only on and off */
+  if (state == OSSO_DISPLAY_DIMMED)
+    return;
+
   g_signal_emit_by_name (G_OBJECT (window),
                          "screen-off",
                          state == OSSO_DISPLAY_OFF);
@@ -1677,6 +1682,10 @@ hd_home_window_background (HDHomeWindow    *window,
   area = GTK_BIN (window)->child;
   g_return_if_fail (HILDON_IS_HOME_AREA (area));
 
+  g_debug ("Background state changed, is_background: %i", is_background);
+
+  priv->is_background = is_background;
+
   if (!priv->screen_is_off)
     {
 
@@ -1710,9 +1719,14 @@ hd_home_window_screen_off (HDHomeWindow         *window,
 
   priv->screen_is_off = is_off;
 
-  gtk_container_foreach (GTK_CONTAINER (area),
-                         (GtkCallback)hildon_desktop_home_item_set_is_background,
-                         (gpointer)is_off);
+  g_debug ("Screen state changed, is_off: %i", is_off);
+
+  if (!priv->is_background)
+    {
+      gtk_container_foreach (GTK_CONTAINER (area),
+                             (GtkCallback)hildon_desktop_home_item_set_is_background,
+                             (gpointer)is_off);
+    }
 
 }
 
