@@ -1304,6 +1304,9 @@ hd_switcher_menu_check_content (HDSwitcherMenu *switcher)
        (GTK_TOGGLE_BUTTON (switcher->priv->toggle_button), FALSE);
   }
 
+  if (!children && switcher->priv->is_open)
+    hildon_desktop_popup_window_jump_to_pane (switcher->priv->popup_window, -1);
+
   g_list_free (children);
 }	
 
@@ -1692,7 +1695,7 @@ hd_switcher_menu_create_applications_menu (HDSwitcherMenu *switcher, HDWM *hdwm)
   hd_switcher_menu_check_content (switcher); 
 
   gtk_widget_queue_draw (GTK_WIDGET (switcher->priv->menu_applications));
-}	
+}
 
 static void 
 hd_switcher_menu_add_info_cb (HDWM *hdwm, 
